@@ -398,7 +398,8 @@ class PolyYaco():
             self._PolyYaco_files = files
 
         if base is not None:
-            self._PolyYaco_files = (('_base', True), ) + self._PolyYaco_files
+            self._PolyYaco_files = (('_base', True), ) +  \
+                tuple(self._PolyYaco_files)
             
         self._PolyYaco_yaco = {}
 
